(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     39990,        787]
NotebookOptionsPosition[     38736,        758]
NotebookOutlinePosition[     39127,        775]
CellTagsIndexPosition[     39084,        772]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Sun Source  (contributed by Ben Jacobson, Illumitech, www.illumitech.com )
\
\>", "Section",
 CellChangeTimes->{{3.418046288453125*^9, 3.4180462895625*^9}, {
  3.425695556079533*^9, 
  3.4256955576234493`*^9}},ExpressionUUID->"5c4c4f02-f27d-4339-a62a-\
fef3e72e7148"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Optica`Optica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.414891670203125*^9, 3.414891684265625*^9}, 
   3.415001134796875*^9, {3.745291119471982*^9, 
   3.745291123994755*^9}},ExpressionUUID->"44acbf58-813e-48a5-bbf6-\
790673312f36"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$HistoryLength", "=", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.414891687453125*^9, 
  3.4148916919375*^9}},ExpressionUUID->"450bffd1-b3d6-4b81-b87d-6022d7b80d15"],

Cell[CellGroupData[{

Cell["\<\
Light sources

( It is noted that to improve this model,  users can set the
grid at the surface of the mirror, and have rays coming in to each point on
the grid with a Monte Carlo angular distribution) \
\>", "Subsection",
 CellChangeTimes->{{3.418121518421875*^9, 3.41812152021875*^9}, {
  3.425695575059341*^9, 
  3.4256956638514423`*^9}},ExpressionUUID->"f5fb3a39-6443-4b5e-ab10-\
9189e59caba4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LambertianDisk", "[", 
   RowBox[{"diam_", ",", "halfangle_", ",", "nrays_", ",", "opts___"}], "]"}],
   ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"posntable", ",", "tilttable"}], "}"}], ",", 
    RowBox[{
     RowBox[{"posntable", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"r", "=", 
             SqrtBox[
              RowBox[{"RandomReal", "[", 
               RowBox[{"{", 
                RowBox[{"0", ",", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   FractionBox["diam", "2"], ")"}], "2"]}], "}"}], "]"}]]}], 
            ",", 
            RowBox[{"\[Theta]", "=", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"2", " ", "\[Pi]"}]}], "}"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"r", " ", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
            RowBox[{"r", " ", 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", "nrays", "}"}]}], "]"}]}], ";", 
     RowBox[{"tilttable", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]", "=", 
             RowBox[{"ArcSin", "[", 
              SqrtBox[
               RowBox[{"RandomReal", "[", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", "halfangle", "]"}], "2"]}], "}"}], 
                "]"}]], "]"}]}], ",", 
            RowBox[{"\[Theta]", "=", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"2", " ", "\[Pi]"}]}], "}"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], ",", 
             RowBox[{
              RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}]}], "}"}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", "nrays", "}"}]}], "]"}]}], ";", 
     RowBox[{"CustomRays", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"RayStart", ",", "posntable"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"RayTilt", ",", "tilttable"}], "}"}]}], "}"}], ",", 
       "opts"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.74529117975774*^9, 
  3.745291180499041*^9}},ExpressionUUID->"f0cc1349-307b-43f4-b97d-\
ed431eba09d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sunsource", "[", 
   RowBox[{
   "xmirror_", ",", "startclearance_", ",", "centerang_", ",", "halfang_", 
    ",", "nrays_"}], "]"}], ":=", 
  RowBox[{"Move", "[", 
   RowBox[{
    RowBox[{"GridOfRays", "[", 
     RowBox[{
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"LambertianDisk", "[", 
         RowBox[{".0001", ",", "halfang", ",", "nrays"}], "]"}], ",", 
        RowBox[{
         RowBox[{"-", "startclearance"}], 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"centerang", "/", "2"}], "]"}], ",", "0", ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             RowBox[{"centerang", "/", "2"}], "]"}]}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"centerang", "/", "2"}], "]"}], ",", "0", ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"centerang", "/", "2"}], "]"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{".95", 
       RowBox[{"{", 
        RowBox[{"4", ",", "6"}], "}"}]}], ",", 
      RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"xmirror", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"centerang", "/", "2"}], "]"}], ",", "0", ",", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{"centerang", "/", "2"}], "]"}]}]}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.4180509490625*^9, 3.4180510903125*^9}, 
   3.418051146890625*^9, 3.41808965515625*^9, {3.41812145946875*^9, 
   3.418121460203125*^9}, {3.41812319275*^9, 3.41812321375*^9}, {
   3.418123997734375*^9, 3.4181240408125*^9}, {3.41812410309375*^9, 
   3.418124129296875*^9}, {3.418124356546875*^9, 3.418124359421875*^9}, 
   3.4181244713125*^9, {3.41868151378125*^9, 
   3.41868151896875*^9}},ExpressionUUID->"56fbc1c5-c2ce-476d-a646-\
c06ccec2cbbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"trackingmirror", "[", 
   RowBox[{"elevnangle_", ",", "xposn_"}], "]"}], ":=", 
  RowBox[{"Move", "[", 
   RowBox[{
    RowBox[{"Mirror", "[", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"xposn", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", 
        RowBox[{"elevnangle", "/", "2"}], "]"}]}], ",", "0", ",", 
      RowBox[{"Sin", "[", 
       RowBox[{"elevnangle", "/", "2"}], "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.418675148234375*^9, 3.418675249359375*^9}, {
  3.418675387609375*^9, 
  3.418675394546875*^9}},ExpressionUUID->"35c486e1-9b31-431c-9abd-\
ff20d216c760"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TurboPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sunsource", "[", 
      RowBox[{"15", ",", "7.5", ",", 
       RowBox[{"15", "Degree"}], ",", 
       RowBox[{"0.25", "Degree"}], ",", "10"}], "]"}], ",", 
     RowBox[{"trackingmirror", "[", 
      RowBox[{
       RowBox[{"15", "Degree"}], ",", "15"}], "]"}], ",", " ", 
     RowBox[{"Boundary", "[", "20", "]"}]}], "}"}], ",", "  ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4256950989956083`*^9, 3.4256951000885553`*^9}, {
  3.42569513518069*^9, 3.425695172002668*^9}, {3.425695220277742*^9, 
  3.425695221634378*^9}},ExpressionUUID->"b42090a9-2112-455b-b75d-\
9f89fe44cd45"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjQc4AyHBhQgJ5DWCgIfLXHLv4UQ5wBK9BzCIGo
349d/CuGOJRxgFjxMBzmhOGwl4A7MfwVgiMcoAwHQuIAL6MlwA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII6748bcbK7rwAAFJX6G7/JPsx94NaklPLwKIT47
482kVzv/7y/1PLRaey+6+Pv9EJ4eXBwGurfZhlxx0kNXby+WW71iRSu6+H/7
Rco7/9ScQIhD3eOASxyXObjsxeVOXP7CFQ64wg2XOAB0o22C
       "], {{
       14.608421423339845`, 2., -2.974334584121431}, {
       14.608421423339845`, -2., -2.974334584121431}, {
       15.391578576660155`, -2., 2.974334584121431}, {15.391578576660155`, 2.,
        2.974334584121431}, {14.608421423339845`, 2., -2.974334584121431}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxIcDEAUKrwOgDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTAPycMGs=
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[0.038747429704798886`, 0.9161617552424038, 0.03984721226918142], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx1nGdQVFcDhrGwdsWGRkVULLGgEiu2iw0+RRTs2CJ2sRfEhr1hRAmWqFiw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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxl2Xk0lPsfwHEl06qUpRJRWkmlUpTbo40bKRJRWpQ2LWTJpVRSoYuE3CIl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      "]]}}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  ImageSize->{360., 403.3740944063343},
  PlotRange:>All,
  ViewPoint->{1.2670020009134806`, -3.136866922914565, -0.06907848873386228},
  ViewVertical->{0.17136698879827608`, -0.5858063550746492, 
   0.7921264226778237}]], "Print",
 CellChangeTimes->{3.42569522624496*^9, 
  3.425695446329073*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"aaad8925-fe0b-4f8f-b50e-d90d30bc0d14"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Printout",
WindowSize->{1084, 1020},
WindowMargins->{{65, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 277, 7, 101, "Section",ExpressionUUID->"5c4c4f02-f27d-4339-a62a-fef3e72e7148"],
Cell[847, 31, 278, 5, 20, "Input",ExpressionUUID->"44acbf58-813e-48a5-bbf6-790673312f36"],
Cell[1128, 38, 202, 4, 20, "Input",ExpressionUUID->"450bffd1-b3d6-4b81-b87d-6022d7b80d15"],
Cell[CellGroupData[{
Cell[1355, 46, 408, 10, 110, "Subsection",ExpressionUUID->"f5fb3a39-6443-4b5e-ab10-9189e59caba4"],
Cell[1766, 58, 2962, 82, 167, "Input",ExpressionUUID->"f0cc1349-307b-43f4-b97d-ed431eba09d3"],
Cell[4731, 142, 1967, 51, 80, "Input",ExpressionUUID->"56fbc1c5-c2ce-476d-a646-c06ccec2cbbc"],
Cell[6701, 195, 750, 21, 36, "Input",ExpressionUUID->"35c486e1-9b31-431c-9abd-ff20d216c760"],
Cell[CellGroupData[{
Cell[7476, 220, 725, 17, 36, "Input",ExpressionUUID->"b42090a9-2112-455b-b75d-9f89fe44cd45"],
Cell[8204, 239, 30492, 514, 408, 23600, 400, "CachedBoxData", "BoxData", "Print",ExpressionUUID->"aaad8925-fe0b-4f8f-b50e-d90d30bc0d14"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

